Documentation
¶
Overview ¶
Copyright (c) 2016, Joel Scoble. All rights reserved.
Use of this source code is governed by the MIT license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Exported ¶
Exported returns the string as a MixedCase string that can be used for exported identifiers.
func LowerFirstRune ¶
LowerFirstRune returns a copy of the string s with the first Unicode letter mapped to its lowercase.
func LowerInitialism ¶
LowerInitialism returns the string as all lower case if it matches a supported initialism, otherwise the original value is returned.
func NumToAlpha ¶
NumToAlpha checks to see if the first char is a number, if it is, it gets converted to its word equivalent. The rest of the string is uppercased if it is an initialism and title cased since it now counts as a seperate word.
func Unexported ¶
Unexported returns the string as a mixedCase string that can be used for unexported identifiers.
func UpperInitialism ¶
UpperInitialism returns the string as all UPPER case if it matches a supported initialism, otherwise the original value is returned.
Types ¶
This section is empty.